@@ -1,9 +1,11 @@
+from typing import TYPE_CHECKING
+
+from .hkObject import hkObject
+from ..enums.SpuCollisionCallbackEventFilter import SpuCollisionCallbackEventFilter
 from ...binary import BinaryReader, BinaryWriter
 from ...binary.types import UInt8, UInt16, UInt32
-from ..enums.SpuCollisionCallbackEventFilter import SpuCollisionCallbackEventFilter
-from .hkObject import hkObject
 
-if False:
+if TYPE_CHECKING:
     from ...hkfile import HKFile
     from ...container.util.hkobject import HKObject
 
