@@ -1,3 +1,5 @@
+from ..StaticCompoundInfo import StaticCompoundInfo
+from ..hkRootLevelContainer import hkRootLevelContainer
 from ..hkaiDirectedGraphExplicitCost import hkaiDirectedGraphExplicitCost
 from ..hkaiNavMesh import hkaiNavMesh
 from ..hkaiStaticTreeNavMeshQueryMediator import hkaiStaticTreeNavMeshQueryMediator
@@ -6,15 +8,16 @@ from ..hkcdStaticTreeDefaultTreeStorage6 import hkcdStaticTreeDefaultTreeStorage
 from ..hkpBoxShape import hkpBoxShape
 from ..hkpBvCompressedMeshShape import hkpBvCompressedMeshShape
 from ..hkpCapsuleShape import hkpCapsuleShape
+from ..hkpConvexTransformShape import hkpConvexTransformShape
+from ..hkpConvexTranslateShape import hkpConvexTranslateShape
 from ..hkpConvexVerticesShape import hkpConvexVerticesShape
 from ..hkpCylinderShape import hkpCylinderShape
+from ..hkpListShape import hkpListShape
 from ..hkpPhysicsData import hkpPhysicsData
 from ..hkpPhysicsSystem import hkpPhysicsSystem
 from ..hkpRigidBody import hkpRigidBody
 from ..hkpSphereShape import hkpSphereShape
 from ..hkpStaticCompoundShape import hkpStaticCompoundShape
-from ..hkRootLevelContainer import hkRootLevelContainer
-from ..StaticCompoundInfo import StaticCompoundInfo
 
 
 class HKClassMap:
@@ -27,8 +30,11 @@ class HKClassMap:
         "hkpBoxShape": hkpBoxShape,
         "hkpBvCompressedMeshShape": hkpBvCompressedMeshShape,
         "hkpCapsuleShape": hkpCapsuleShape,
+        "hkpConvexTransformShape": hkpConvexTransformShape,
+        "hkpConvexTranslateShape": hkpConvexTranslateShape,
         "hkpConvexVerticesShape": hkpConvexVerticesShape,
         "hkpCylinderShape": hkpCylinderShape,
+        "hkpListShape": hkpListShape,
         "hkpPhysicsData": hkpPhysicsData,
         "hkpPhysicsSystem": hkpPhysicsSystem,
         "hkpRigidBody": hkpRigidBody,
@@ -46,4 +52,4 @@ class HKClassMap:
         try:
             return HKClassMap.hk_class_map[name]
         except KeyError:
-            raise NotImplementedError(f"Class '{name}' is not implemented yet!")
+            raise SystemExit(f"Class '{name}' is not implemented yet!")
